
import 'dart:convert';
import 'dart:io';

import 'package:flutter/material.dart';
import 'package:path_provider/path_provider.dart';

import '../../abg_utils.dart';

Future<String?> loadLangsFromLocal(String locale,
    String needLocale, Function(LangData lang) setLang, Function(List<LangData> lang) setLangs) async {
  try{
    var directory = await getApplicationDocumentsDirectory();
    var directoryPath = directory.path;
    var _file = File('$directoryPath/listlangs.json');
    if (!await _file.exists())
      return null;
    final contents = await _file.readAsString();
    var data = json.decode(contents);
    dprint("loadLangsFromLocal $data");
    var t = data.map((f) => LangData.fromJson(f)).cast<LangData>().toList();
    setLangs(t); // parent.appLangs = t;
    dprint("loadLangsFromLocal appLangs ${t.appLangs}");
    for (var item in t.appLangs){
      var _doc = "${item.app}_${item.locale}";
      var _file = File('$directoryPath/$_doc.json');
      if (!await _file.exists())
        return null;
      final contents = await _file.readAsString();
      dprint('read local lang $directoryPath/$_doc.json');
      item.data = json.decode(contents);
      if (locale.isNotEmpty){
        if (locale == item.locale)
          setLang(item); //item.data, item.locale, context, item.direction);
      }else
      if (needLocale == item.locale)
        setLang(item); // item.data, item.locale, context, item.direction);
    }
  }catch(ex){
    return "model loadLangsFromLocal " + ex.toString();
  }
  return null;
}



class LangData{
  LangData({required this.name, required this.engName, this.image = "",
    required this.direction, required this.locale, this.app = "service", required this.data});
  String name;
  String engName;
  String image;
  TextDirection direction;
  String locale;
  String app;
  Map<String, dynamic> data;

  Map toJson() => {
    'name' : name,
    'engName' : engName,
    'direction' : direction == TextDirection.ltr ? "ltr" : 'rtl',
    'locale' : locale,
    'app' : app
  };

  factory LangData.fromJson(Map<String, dynamic> data){
    return LangData(
        name: data["name"] ?? "",
        engName: data["engName"] ?? "",
        app: data["app"] ?? "service",
        direction: data["direction"] != null ? data["direction"] == "ltr" ? TextDirection.ltr : TextDirection.rtl : TextDirection.ltr,
        locale: data["locale"] ?? "",
        data: {}
    );
  }
}